@@ -41,13 +41,24 @@ class ContigSequences:
         self._fa = None  # type: Optional[Dict[str, int]]
 
     def _read_fa(self) -> Dict[str, Sequence]:
-        """Read and index fasta."""
+        """Read and index fasta.
+
+        If there are >1 repeated space in the header it is reduced to 1.
+        """
+        def _rm_repeated_spaces(header):
+            """Reduce headers with multiple repeated spaces to one.
+
+            This mimics the header format blast reports.
+            """
+            return re.sub('\s+', ' ', header)
+
         if self._fa is None:
-            self._fa = {s.title: s for s in read_fasta_file(self._file_path)}
+            self._fa = {_rm_repeated_spaces(s.title): s
+                        for s
+                        in read_fasta_file(self._file_path)}
         return self._fa
 
-    def sub_sequence(self, start: int, end: int, strand: int,
-                     contig: str) -> Sequence:
+    def sub_sequence(self, start: int, end: int, strand: int, contig: str) -> Sequence:
         """Get sub-sequence from start-end from contig with header."""
         if start < 0 or end < 0:
             raise CoordinateError
@@ -62,6 +73,7 @@ class ContigSequences:
         seq = seq if strand == 1 else reverse_complement(seq)
         return Sequence(title=None, seq=seq)
 
+
     def __len__(self):
         """Return num sequences."""
         return len(self._read_fa())
@@ -71,6 +83,10 @@ class ContigSequences:
         for seq in self._read_fa().values():
             yield seq
 
+def _clean_contig_header(header):
+    """Ensure that the contig header conforms a valid fasta format."""
+    return header
+
 
 def _find_version(args: List[str], pattern: str) -> str:
     """Find version of program invoked by arguments.
@@ -91,10 +107,13 @@ def _find_version(args: List[str], pattern: str) -> str:
                          process.stdout)
 
 
-def read_fasta_file(path: str):
-    """Read fasta file and return fasta sequence object."""
-    with open(path) as f:
-        for header, seq in SimpleFastaParser(f):
+def read_fasta_file(path: str, header_fmt_func=None):
+    """Read fasta file and return fasta sequence object.
+
+    The headers can be processed by passing a function to header_fmt_func
+    """
+    with open(path) as fh:
+        for header, seq in SimpleFastaParser(fh):
             yield Sequence(title=header, seq=seq)
 
 
