@@ -275,6 +275,21 @@ def _get_exec_path(path: str) -> Optional[str]:
     return exec_path
 
 
+def _validate_blast_json(path: str) -> bool:
+    """Validate the integrity of a cached blast result file."""
+    LOG.debug('Validate blast json')
+    try:
+        with open(path) as jsfile:
+            js = json.load(jsfile)
+    except json.decoder.JSONDecodeError:
+        LOG.warning('JSON file is invalid')
+        return False
+    # verify its content
+    if 'BlastOutput2' not in js:
+        return False
+    return True
+
+
 def make_database(db: MGEdb, makedb_exec, path=None) -> None:
     """Make blast database from MGEdb in path specifed in BLASTDB env variable."""
     db_dir = pathlib.Path(os.environ.get('BLASTDB'))  # type: ignore
@@ -297,8 +312,11 @@ def run_blast(ctx: ExecutionContext, db_name: str, contigs: str) -> str:
     # check if blast results already exists
     blast_result_path: str = ctx.file_path('blast', '%s_blast.json' % db_name)
     if os.path.isfile(blast_result_path):
-        LOG.info(f'using cached blast result: {blast_result_path}')
-        return blast_result_path
+        if _validate_blast_json(blast_result_path):
+            LOG.info(f'using cached blast result: {blast_result_path}')
+            return blast_result_path
+        else:
+            LOG.warning(f'Cached blast results are invalid, reanalyze files')
 
     # Get BLAST path
     blast_path = _get_exec_path(ctx.blastn_path)
